/* GCC */
#include <iostream>
#include <cstdio>
#include <cstdlib>
#include <ctime>
#include <cmath>
#include <cstring>
#include <string>
#include <vector>
#include <map>
#include <algorithm>
#include <queue>
#include <sstream>
#include <locale.h>

#define X first
#define Y second
#define mp(a, b) make_pair((a), (b))

using namespace std;

int gcd(int a, int b)
{
    a = abs(a);
    b = abs(b);

    while(b > 0)
    {
        a = a % b;
        swap(a, b);
    }

    return a;
}

struct frac
{
    int p, q;

    frac()
    {
        p = 0;
        q = 1;
    }

    frac(int pp)
    {
        p = pp;
        q = 1;
    }

    void simplify()
    {
        int d = gcd(p, q);
        if(d > 1)
        {
            p = p / d;
            q = q / d;
        }

        if(q < 0)
        {
            p = -p;
            q = -q;
        }

        if(p == 0)
        {
            q = 1;
        }
    }

    void print()
    {
        printf("%d", p);
        if(q != 1)
            printf("/%d", q);
    }
};

inline frac operator+ (frac a, frac b)
{
    frac r;
    r.p = (a.p * b.q + b.p * a.q);
    r.q = a.q * b.q;
    r.simplify();
    return r;
}

inline frac operator* (frac a, frac b)
{
    frac r;
    r.p = a.p * b.p;
    r.q = a.q * b.q;
    r.simplify();
    return r;
}

inline bool operator< (frac a, frac b)
{
    return ((a.p * b.q) < (b.p * a.q));
}

inline bool operator== (frac a, frac b)
{
    return ((a.p == b.p) && (a.q == b.q));
}

struct line
{
    int a, b, c;

    line()
    {
        a = 0;
        b = 0;
        c = 0;
    }

    line(int X1, int Y1, int X2, int Y2)
    {
        a = Y2 - Y1;
        b = X1 - X2;
        c = -(X1 * a + Y1 * b);

        int d = gcd(a, gcd(b, c));
        if(d > 1)
        {
            a = a / d;
            b = b / d;
            c = c / d;
        }

        if(a < 0 || (a == 0 && b < 0))
        {
            a = -a;
            b = -b;
            c = -c;
        }
    }
};

pair <frac, frac> intersect(line l1, line l2)
{
    pair <frac, frac> r;

    r.X.p = l1.c * l2.b - l2.c * l1.b;
    r.X.q = l2.a * l1.b - l1.a * l2.b;
    r.X.simplify();

    r.Y.p = l1.c * l2.a - l2.c * l1.a;
    r.Y.q = l2.b * l1.a - l1.b * l2.a;
    r.Y.simplify();

    return r;
}

frac distan(pair <frac, frac> r, line l)
{
    frac d;

    d = frac(l.a) * r.X + frac(l.b) * r.Y + frac(l.c);
    d.q *= int(sqrt(l.a * l.a + l.b * l.b) + 0.5);
    d.simplify();

    if(d.p < 0)
        d.p = -d.p;

    return d;
}

frac distan(line l1, line l2)
{
    frac d;

    d.p = abs(l1.c - l2.c);
    d.q = int(sqrt(l1.a * l1.a + l1.b * l1.b) + 0.5);
    d.simplify();

    return d;
}

int n, i, j, k;
int X1, Y1, X2, Y2;
bool flag;

line l1, l2;
vector <line> lines;

pair <frac, frac> point;
vector < pair <frac, frac> > points;

frac dist, min_dist;
vector < pair <frac, frac> > best_points;
vector <line> best_lines;

int main()
{
    freopen("motel.in", "r", stdin);
    freopen("motel.out", "w", stdout);

    scanf("%d", &n);
    for(i = 0; i < n; i++)
    {
        scanf("%d %d %d %d", &X1, &Y1, &X2, &Y2);
        lines.push_back(line(X1, Y1, X2, Y2));
    }

    for(i = 0; i < n - 1; i++)
        for(j = i + 1; j < n; j++)
        {
            l1 = lines[i];
            l2 = lines[j];

            if(l1.a == l2.a && l1.b == l2.b)
                continue;

            point = intersect(l1, l2);

            flag = false;
            for(k = 0; k < points.size(); k++)
                if(points[k] == point)
                {
                    flag = true;
                    break;
                }

            if(flag == false)
                points.push_back(point);
        }

    if(points.size() > 0)
    {
        min_dist.q = 0;

        for(i = 0; i < points.size(); i++)
        {
            dist = frac();

            for(j = 0; j < n; j++)
                dist = dist + distan(points[i], lines[j]);

            if(min_dist.q == 0)
            {
                min_dist = dist;
                best_points.push_back(points[i]);
            }
            else if(dist < min_dist)
            {
                min_dist = dist;
                best_points.clear();
                best_points.push_back(points[i]);
            }
            else if(dist == min_dist)
                best_points.push_back(points[i]);
        }

        min_dist.print();
        printf("\n");
        printf("%d\n", best_points.size());
        for(i = 0; i < best_points.size(); i++)
        {
            best_points[i].X.print();
            printf(" ");
            best_points[i].Y.print();
            printf("\n");
        }
    }
    else
    {
        min_dist.q = 0;

        for(i = 0; i < n; i++)
        {
            dist = frac();

            for(j = 0; j < n; j++)
                dist = dist + distan(lines[i], lines[j]);

            if(min_dist.q == 0)
            {
                min_dist = dist;
                best_lines.push_back(lines[i]);
            }
            else if(dist < min_dist)
            {
                min_dist = dist;
                best_lines.clear();
                best_lines.push_back(lines[i]);
            }
            else if(dist == min_dist)
                best_lines.push_back(lines[i]);
        }

        min_dist.print();
        printf("\n");
        printf("%d\n", -best_lines.size());
        for(i = 0; i < best_lines.size(); i++)
        {
            printf("%d", best_lines[i].a);
            printf(" ");
            printf("%d", best_lines[i].b);
            printf(" ");
            printf("%d", best_lines[i].c);
            printf("\n");
        }
    }

    return 0;
}

















