/* GCC */
#include <iostream>
#include <fstream>
#include <vector>
#include <algorithm>
#include <set>
#include <queue>

using namespace std;
const int dr[4] = {-1, 0, 1, 0}, dc[4] = {0, 1, 0, -1};

struct point
{
    point(int _r, int _c)
        : r(_r), c(_c)
    {}
    int r;
    int c;
};

struct figure
{
    figure(void)
        : pt_cnt(0), min_r(1000), max_r(-1), min_c(1000), max_c(-1)
    {}
    int pt_cnt;
    int min_r;
    int max_r;
    int min_c;
    int max_c;
};

char gr_in[528][528], curf[528][528], cl_curf[528][528];
unsigned char gr[528][528] = {};
int n, cur_figure = 1, cnt_figures, cnt_dif, nr, nc, h1, w1, h2, w2;
figure figures[249]; // [1; 248]
bool used[249] = {};

inline bool valid(int r, int c)
{
    return r >= 0 && c >= 0 && r < n && c < n;
}

void bfs(int r, int c)
{
    queue<point> q;
    q.push(point(r, c));
    while(!q.empty())
    {
        const point cur_pt = q.front();
        q.pop();
        gr[cur_pt.r][cur_pt.c] = cur_figure;
        ++figures[cur_figure].pt_cnt;
        if(cur_pt.r < figures[cur_figure].min_r)
            figures[cur_figure].min_r = cur_pt.r;
        if(cur_pt.r > figures[cur_figure].max_r)
            figures[cur_figure].max_r = cur_pt.r;
        if(cur_pt.c < figures[cur_figure].min_c)
            figures[cur_figure].min_c = cur_pt.c;
        if(cur_pt.c > figures[cur_figure].max_c)
            figures[cur_figure].max_c = cur_pt.c;
        for(int d = 0; d < 4; ++d)
        {
            nr = cur_pt.r + dr[d], nc = cur_pt.c + dc[d];
            if(valid(nr, nc) && gr_in[nr][nc] != ' ' && gr[nr][nc] == 0)
                q.push(point(nr, nc));
        }
    }
}

inline void reclone(void)
{
    for(int i = 0; i < h2; ++i)
        for(int j = 0; j < w2; ++j)
            curf[i][j] = cl_curf[i][j];
}

void rotate_cw(void)
{
    for(int i = 0; i < h2; ++i)
        for(int j = 0; j < w2; ++j)
            cl_curf[j][h2 - i - 1] = curf[i][j];
    swap(h2, w2);
    reclone();
}

void hor_sym(void)
{
    for(int i = 0; i < h2; ++i)
        for(int j = 0; j < w2; ++j)
            cl_curf[h2 - 1 - i][j] = curf[i][j];
    reclone();
}

void ver_sym(void)
{
    for(int i = 0; i < h2; ++i)
        for(int j = 0; j < w2; ++j)
            cl_curf[i][w2 - 1 - j] = curf[i][j];
    reclone();
}

bool parallel(int fig1)
{
    if(h1 != h2 || w1 != w2)
        return false;
    const figure& f1 = figures[fig1];
    for(int i = f1.min_r; i <= f1.max_r; ++i)
        for(int j = f1.min_c; j <= f1.max_c; ++j)
            if(curf[i - f1.min_r][j - f1.min_c] != (gr[i][j] == fig1 ? fig1 : 0))
                return false;
    return true;
}

bool eq(int fig1, int fig2)
{
    const figure& f1 = figures[fig1], f2 = figures[fig2];
    if(f1.pt_cnt != f2.pt_cnt)
        return false;
    h1 = f1.max_r - f1.min_r + 1, w1 = f1.max_c - f1.min_c + 1;
    h2 = f2.max_r - f2.min_r + 1, w2 = f2.max_c - f2.min_c + 1;
    if(min(w1, h1) != min(w2, h2) || max(w1, h1) != max(w2, h2))
        return false;
    for(int i = f2.min_r; i <= f2.max_r; ++i)
        for(int j = f2.min_c; j <= f2.max_c; ++j)
            curf[i - f2.min_r][j - f2.min_c] = (gr[i][j] == fig2 ? fig1 : 0);
    if(parallel(fig1))
        return true;
    rotate_cw();
    if(parallel(fig1))
        return true;
    rotate_cw();
    if(parallel(fig1))
        return true;
    rotate_cw();
    if(parallel(fig1))
        return true;
    rotate_cw();
    hor_sym();
    if(parallel(fig1))
        return true;
    rotate_cw();
    if(parallel(fig1))
        return true;
    rotate_cw();
    rotate_cw();
    if(parallel(fig1))
        return true;
    rotate_cw();
    hor_sym();
    ver_sym();
    if(parallel(fig1))
        return true;
    return false;
}

int main(void)
{
    ios_base::sync_with_stdio(false);
    ifstream in("test.in");
    in >> n;
    in.get();
    for(int i = 0; i < n; ++i)
        in.getline(gr_in[i], 1000);
    in.close();
    for(int i = 0; i < n; ++i)
        for(int j = 0; j < n; ++j)
            if(gr_in[i][j] != ' ' && gr[i][j] == 0)
            {
                bfs(i, j);
                ++cur_figure;
            }
    cnt_dif = cnt_figures = cur_figure - 1;
    for(cur_figure = 2; cur_figure <= cnt_figures; ++cur_figure)
        for(int lfig = 1; lfig < cur_figure; ++lfig)
            if(!used[lfig] && eq(cur_figure, lfig))
            {
                used[cur_figure] = true, --cnt_dif;
                break;
            }
    ofstream out("test.out");
    out << cnt_figures << ' ' << cnt_dif << '\n';
    out.close();
	return 0;
}
